@@ -16,11 +16,12 @@
 # along with mrgsolve.  If not, see <http://www.gnu.org/licenses/>.
 
 
-##' Get THETA, OMEGA and SIGMA from a completed NONMEM run
+##' Import model estimates from a NONMEM xml file
 ##'
 ##' @param run run number
 ##' @param project project directory
-##' @param file the complete path to the \code{run.xml} file
+##' @param path the complete path to the \code{run.xml} file
+##' @param file deprecated; use \code{path} instead
 ##' @param theta logical; if TRUE, the \code{$THETA} vector is returned
 ##' @param omega logical; if TRUE, the \code{$OMEGA} matrix is returned
 ##' @param sigma logical; if TRUE, the \code{$SIGMA} matrix is returned
@@ -36,7 +37,6 @@
 ##' estimation results to return
 ##' @param xpath xml path containing run results; if the default doesn't work, 
 ##' consider using \code{.//estimation} as an alternative; see details
-##' @param ... not used
 ##' @aliases NMXML
 ##' @details
 ##' If \code{run} and \code{project} are supplied, the .xml file is 
@@ -56,7 +56,9 @@
 ##' 
 ##' @return A list with theta, omega and sigma elements, 
 ##' depending on what was requested
-##' 
+##'  
+##' @seealso nmext
+##'  
 ##' @examples
 ##' 
 ##' if(requireNamespace("xml2")) {
@@ -65,24 +67,32 @@
 ##' }
 ##' 
 nmxml <- function(run=numeric(0), project=character(0),
-                  file=character(0),
+                  file=character(0), path = character(0),
                   theta=TRUE, omega=TRUE, sigma=TRUE,
                   olabels = NULL, slabels = NULL,
                   oprefix = "", sprefix="",
                   tname="THETA", oname="...", sname="...",
                   index = "last",
-                  xpath = ".//nm:estimation",
-                  ...) {
+                  xpath = ".//nm:estimation") {
   
   theta <- theta | !missing(tname)
   omega <- omega | !missing(oname)
   sigma <- sigma | !missing(sname)
   
   if(!missing(file)) {
-    target <- file
+    lifecycle::deprecate_soft(
+      "0.10.2", 
+      "mrgsolve::nmxml(file = )", 
+      "nmxml(path = )"
+    )
+    path <- file
+  }
+  
+  if(!missing(path)) {
+    target <- path
   } else {
     if(missing(run) | missing(project)) {
-      stop("Both file and run/project are missing.", call.=FALSE)
+      wstop("both file and run or project are missing")
     }
     target <- file.path(project, run, paste0(run, ".xml"))
   }
@@ -126,7 +136,25 @@ nmxml <- function(run=numeric(0), project=character(0),
     stopifnot(nchar(tname) > 0)
     th <- sapply(tree$theta, "[", USE.NAMES=FALSE)
     th <- as.list(as.numeric(th))
-    names(th) <- paste0(tname, seq(length(th)))
+    
+    if(length(tname) > 1) {
+      if(length(tname) != length(th)) {
+        wstop(
+          "'tname' length (", 
+          length(tname), 
+          ") is not equal to ",
+          "number of THETAs (", 
+          length(th), 
+          ")"
+        )
+      }
+    }
+    
+    if(length(th) == length(tname)) {
+      names(th) <- tname
+    } else {
+      names(th) <- paste0(tname, seq(length(th)))
+    }
   }
   
   if(omega) {
@@ -173,6 +201,86 @@ nmxml <- function(run=numeric(0), project=character(0),
   
 }
 
+#' Import model estimates from a NONMEM ext file
+#' 
+#' @inheritParams nmxml
+#' @param path full path to NONMEM `ext` file
+#' @param read_fun function to use when reading the `ext` file
+#' 
+#' @seealso [nmxml], [read_nmext]
+#' 
+#' @md
+nmext <- function(run=NA_real_, project=getwd(), 
+                  file=paste0(run,".ext"), path = NULL,
+                  theta=TRUE, omega=TRUE, sigma=TRUE,
+                  olabels = NULL, slabels = NULL,
+                  oprefix = "", sprefix="",
+                  tname="THETA", oname="...", sname="...", 
+                  read_fun = "data.table") {
+  
+  if(missing(run) && !is.character(path)) {
+    wstop("either 'run' or 'path' argument must be specified")  
+  }
+  
+  ans <- read_nmext(run,project,file,path,read_fun)
+  
+  theta <- theta | !missing(tname)
+  omega <- omega | !missing(oname)
+  sigma <- sigma | !missing(sname)
+  
+  th <- list()
+  om <- matrix(0,0,0)
+  sg <- matrix(0,0,0)
+  
+  if(theta) {
+    th <- ans[["param"]]
+    if(tname!="THETA") {
+      names(th) <- sub("THETA", tname, names(th), fixed = TRUE)  
+    }
+  }
+  
+  if(omega) {
+    stopifnot(nchar(oname) > 0)
+    om <- ans[["omega"]]
+    if(is.null(olabels)) {
+      olabels <- rep('.', nrow(om))
+    } else {
+      olabels <- paste0(oprefix,olabels)
+    }
+    olabels <- list(olabels)
+  } else {
+    olabels <- list()
+  }
+  
+  if(sigma) {
+    stopifnot(nchar(sname) > 0)
+    sg <- ans[["sigma"]]
+    if(is.null(slabels)) {
+      slabels <- rep('.', nrow(sg))
+    } else {
+      slabels <- paste0(sprefix,slabels)
+    }
+    slabels <- list(slabels)
+  } else {
+    slabels <- list()
+  }
+  
+  om <- create_matlist(
+    setNames(list(om),oname), 
+    labels=olabels, 
+    class="omegalist"
+  )
+  
+  sg <- create_matlist(
+    setNames(list(sg),sname), 
+    labels=slabels, 
+    class="sigmalist"
+  )
+  
+  ans <- list(theta = th, omega = om, sigma = sg)
+  
+  return(structure(ans,class="NMXMLDATA"))
+}
 
 nm_xml_matrix <- function(x) {
   m <- matrix(0,nrow = length(x), ncol = length(x))
@@ -194,6 +302,7 @@ nm_xml_matrix <- function(x) {
 ##' @param project the NONMEM project directory
 ##' @param file the `ext` file name
 ##' @param path full path and file name for `ext` file
+##' @param read_fun function to read the `ext` file
 ##' 
 ##' @return A list with param, omega, and sigma in a format
 ##' ready to be used to update a model object.
@@ -211,22 +320,50 @@ nm_xml_matrix <- function(x) {
 ##' 
 ##' @md
 ##' @export 
-read_nmext <- function(run, project = getwd(), file = paste0(run, ".ext"), 
-                       path=NULL) {
+read_nmext <- function(run=NA_real_, project = getwd(), file=paste0(run,".ext"), 
+                       path=NULL, read_fun = c("data.table","read.table")) {
+  
   if(is.character(path)) {
-    file <- path
+    extfile <- path  
   } else {
-    file <- file.path(project, run, file)  
+    extfile <- file.path(project,run,file)
   }
-  if(!file.exists(file)) {
-    stop("The file ", file, " does not exist.", call. = FALSE)
+  
+  if(!file.exists(extfile)) {
+    wstop("[read_nmext] could not find the requested 'ext' file ", 
+          shQuote(basename(extfile)))
   }
-  df <- read.table(file, skip = 1, header = TRUE)
+  
+  read_fun <- match.arg(read_fun)
+  
+  use_dt <- requireNamespace("data.table",quietly=TRUE) & read_fun=="data.table"
+  
+  if(use_dt) {
+    df <- data.table::fread(
+      file=extfile, 
+      na.strings = '.', 
+      data.table=FALSE,
+      skip=1
+    )
+  } else {
+    df <- read.table(
+      file=extfile,
+      na.strings='.',
+      stringsAsFactors=FALSE,
+      skip=1, 
+      header=TRUE
+    )
+  }
+  
   ans <- df[df[["ITERATION"]] == -1E9,]
-  if(nrow(ans) != 1) {
-    stop("Could not find estimates in the file: ", basename(file), 
-         call. = FALSE)
+  
+  if(nrow(ans)==0) {
+    wstop(
+      "[read_nmext] could not find final estimates",
+      " while reading 'ext' file ", shQuote(basename(extfile))
+    )
   }
+  
   ans <- as.list(ans)
   names(ans) <- gsub("[[:punct:]]", "", names(ans))
   ans <- list(
