@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2019  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2020  Metrum Research Group
 #
 # This file is part of mrgsolve.
 #
@@ -62,7 +62,7 @@ test_that("combine_list", {
 
 
 
-mod <- mrgsolve:::house()
+mod <- mrgsolve::house()
 out <- mrgsim(mod)
 
 test_that("Corecing simulated output to data.frame", {
